@@ -31,22 +31,19 @@
 
 import re as rgex
 from argparse import ArgumentParser as argument_parser_t
+from pathlib import Path as path_t
 from typing import Any, Iterator, Sequence
 
-import colorama as clrm
-
-from conf_ini_g.interface.console.generic import DisplayErrorAndQuit
-from conf_ini_g.raw.config import ini_config_h, raw_config_h
+from conf_ini_g.extension.string import Flattened
+from conf_ini_g.raw.config import raw_config_h
 from conf_ini_g.specification.config import config_t
-from conf_ini_g.specification.default import missing_required_value_t
-from conf_ini_g.standard.str_extension import Flattened
-
+from conf_ini_g.specification.parameter.value import MISSING_REQUIRED_VALUE
 
 parsed_arguments_h = dict[str, str]
 
 
 # Specified INI document file is stored in INI_DOCUMENT_VARIABLE
-INI_DOCUMENT_VARIABLE = "ini_document"
+INI_DOCUMENT_VARIABLE = "ini_path"
 
 ADVANCED_MODE_OPTION = "advanced-mode"
 ADVANCED_MODE_VARIABLE = "advanced_mode"
@@ -60,6 +57,7 @@ def CommandLineParser(
 ) -> argument_parser_t:
     """"""
     output = argument_parser_t(description=description, allow_abbrev=False)
+    # TODO: Why is this argument optional?
     output.add_argument(
         dest=INI_DOCUMENT_VARIABLE,
         help="Path to INI configuration file",
@@ -73,31 +71,32 @@ def CommandLineParser(
             option = f"{section.name}{SECTION_PARAMETER_SEPARATOR}{parameter.name}"
             if option == ADVANCED_MODE_OPTION:
                 # Raising an exception is adapted here since execution has been launched from command line
-                DisplayErrorAndQuit(
-                    f"{option}: Configuration section and parameter colliding with advanced mode option"
+                raise ValueError(
+                    f"{option}: Command-line option for parameter is identical to advanced mode option. "
+                    f"Please change parameter specification (section name and/or parameter name)."
                 )
 
             attribute = f"{section.name}{SECTION_PARAMETER_SEPARATOR}{parameter.name}"
 
-            # Default is a missing_required_value_t instance to avoid overwriting if in INI but not passed
-            type_options = parameter.type_options
-            default = missing_required_value_t.NewFromConstrainedType(type_options)
+            # Default is a missing_required_value_t instance to avoid overwriting if in
+            # INI but not passed.
+            default = MISSING_REQUIRED_VALUE
 
             if parameter.optional:
                 if isinstance(parameter.default, str):
                     delimiter = '"'
                 else:
                     delimiter = ""
-                types_and_value = (
-                    f"Options: {type_options}. "
-                    f"Default: {clrm.Fore.GREEN}{delimiter}{parameter.default}{delimiter}{clrm.Fore.RESET}"
+                type_and_value = (
+                    f"Type: {parameter.type}. "
+                    f"Default: [green]{delimiter}{parameter.default}{delimiter}[/]"
                 )
             else:
-                types_and_value = str(default)
-            flattened = Flattened(types_and_value)
+                type_and_value = str(default)
+            flattened = Flattened(type_and_value)
             definition = f"{parameter.definition}. {flattened}"
 
-            # Type could be PythonTypeOfAnnotated(cmd_line_type). However, to allow passing any of the allowed types,
+            # Type could be TypeOfAnnotatedHint(cmd_line_type). However, to allow passing any of the allowed types,
             # deferring type validation to functional config instantiation, this parameter is not passed.
             output.add_argument(
                 f"--{option}",
@@ -119,7 +118,7 @@ def CommandLineParser(
 
 def ParsedArguments(
     parser: argument_parser_t, /, *, arguments: Sequence[str] = None
-) -> tuple[str | None, bool, raw_config_h]:
+) -> tuple[path_t | None, bool, raw_config_h]:
     """"""
     parsed, unknowns = parser.parse_known_args(args=arguments)
     parsed = vars(parsed)
@@ -127,8 +126,10 @@ def ParsedArguments(
     advanced_mode = parsed[ADVANCED_MODE_VARIABLE]
     del parsed[ADVANCED_MODE_VARIABLE]
 
-    ini_document = parsed[INI_DOCUMENT_VARIABLE]
+    ini_path = parsed[INI_DOCUMENT_VARIABLE]
     del parsed[INI_DOCUMENT_VARIABLE]
+    if ini_path is not None:
+        ini_path = path_t(ini_path).resolve(strict=True)
 
     pattern = rgex.compile(
         r"--(\w+)" + SECTION_PARAMETER_SEPARATOR + r"(\w+)=(.+)", flags=rgex.ASCII
@@ -137,45 +138,21 @@ def ParsedArguments(
         match = pattern.fullmatch(unknown)
         if match is None:
             # Raising an exception is adapted here since execution has been launched from command line
-            DisplayErrorAndQuit(
+            raise ValueError(
                 f"{unknown}: Invalid option syntax; Expected=--SECTION-PARAMETER=VALUE"
             )
 
         section, parameter, value = match.groups()
         parsed[f"{section}{SECTION_PARAMETER_SEPARATOR}{parameter}"] = value
 
-    parsed_as_ini = {}
+    raw_config = {}
     for sct_name, prm_name, value in _SectionParameterValueIterator(parsed):
-        if sct_name in parsed_as_ini:
-            parsed_as_ini[sct_name][prm_name] = value
+        if sct_name in raw_config:
+            raw_config[sct_name][prm_name] = value
         else:
-            parsed_as_ini[sct_name] = {prm_name: value}
+            raw_config[sct_name] = {prm_name: value}
 
-    return ini_document, advanced_mode, parsed_as_ini
-
-
-def TransferArgumentsToINIConfig(
-    arguments: raw_config_h, config: ini_config_h, specification: config_t
-) -> None:
-    """
-    Raising an exception is adapted here since execution has been launched from command line
-    """
-    for sct_name, parameters in arguments.items():
-        if sct_name not in specification:
-            DisplayErrorAndQuit(
-                f"{sct_name}: Invalid section; Expected={specification.valid_section_names}"
-            )
-        section = specification[sct_name]
-
-        for prm_name, value in parameters.items():
-            if (prm_name in section) or section.accept_unknown_parameters:
-                if sct_name not in config:
-                    config[sct_name] = {}
-                config[sct_name][prm_name] = value
-            else:
-                DisplayErrorAndQuit(
-                    f"{sct_name}.{prm_name}: Attempt to add an unknown parameter to a section accepting none"
-                )
+    return ini_path, advanced_mode, raw_config
 
 
 def _SectionParameterValueIterator(
@@ -183,8 +160,8 @@ def _SectionParameterValueIterator(
 ) -> Iterator[tuple[str, str, Any]]:
     """"""
     for prm_uid, value in arguments.items():
-        # See CommandLineParser for why this can happen
-        if isinstance(value, missing_required_value_t):
+        # See CommandLineParser for why this can happen.
+        if value is MISSING_REQUIRED_VALUE:
             continue
 
         section, parameter = prm_uid.split(SECTION_PARAMETER_SEPARATOR)
