@@ -29,26 +29,22 @@
 # The fact that you are presently reading this means that you have had
 # knowledge of the CeCILL license and that you accept its terms.
 
-import configparser as cfpr
 import sys as sstm
 from argparse import ArgumentParser as argument_parser_t
 
-import conf_ini_g.specification.unit as unit
-from conf_ini_g.interface.storage.constant import INI_COMMENT_MARKER
-from conf_ini_g.raw.config import AsStr, any_raw_config_h, ini_config_h
-from conf_ini_g.specification.default import missing_required_value_t
-from conf_ini_g.specification.parameter import parameter_t
-from conf_ini_g.specification.section import section_t
-from conf_ini_g.standard.path_extension import (
+from conf_ini_g.extension.parser.value_as_string import AsInterpretedObject
+from conf_ini_g.extension.path import (
     ValidateInputPath,
     ValidateOutputPath,
     any_path_h,
     path_t,
 )
-from conf_ini_g.standard.str_extension import EvaluatedValue
+from conf_ini_g.raw.config import AsStr, INIConfigFromINIDocument, any_raw_config_h
+from conf_ini_g.specification.parameter.main import parameter_t
+from conf_ini_g.specification.section.main import section_t
+from conf_ini_g.specification.section.unit import IsUnitSection
 
-
-INI_VALUE_ASSIGNEMENT = "="
+SECTIONS = "SECTIONS"
 
 
 def DraftSpecificationFromINIDocument(path: any_path_h, /) -> str | None:
@@ -60,18 +56,16 @@ def DraftSpecificationFromINIDocument(path: any_path_h, /) -> str | None:
     sections = []
     for section_name, parameters in ini_config.items():
         # possibly_fuzzy=True: in case the raw config is not valid in that respect
-        if unit.IsUnitSection(section_name, possibly_fuzzy=True):
+        if IsUnitSection(section_name, possibly_fuzzy=True):
             continue
 
         parameters_as_lst = []
         for parameter_name, value_as_str in parameters.items():
-            value, _ = EvaluatedValue(value_as_str)
-            py_type = type(value)
-
+            value, _ = AsInterpretedObject(value_as_str)
             parameter = (
                 f"{parameter_t.__name__}(\n"
                 f'                name="{parameter_name}",\n'
-                f"                default={missing_required_value_t.__name__}(types={py_type.__name__})\n"
+                f"                type={type(value).__name__},\n"
                 f"            )"
             )
             parameters_as_lst.append(parameter)
@@ -89,40 +83,14 @@ def DraftSpecificationFromINIDocument(path: any_path_h, /) -> str | None:
 
     imports = (
         f"# To use this specification file:\n"
-        f"#     1. import the object SECTIONS\n"
+        f"#     1. import the object {SECTIONS}\n"
         f"#     2. instantiate a conf_ini_g.specification.config.config_t from it\n"
-        f"from conf_ini_g.specification.default import {missing_required_value_t.__name__}\n"
-        f"from conf_ini_g.specification.parameter import {parameter_t.__name__}\n"
-        f"from conf_ini_g.specification.section import {section_t.__name__}\n"
+        f"from conf_ini_g.specification.parameter.main "
+        f"import {parameter_t.__name__}\n"
+        f"from conf_ini_g.specification.section.main import {section_t.__name__}\n"
     )
 
-    return imports + "\nSECTIONS = (\n" + ",\n".join(sections) + ",\n)\n"
-
-
-def INIConfigFromINIDocument(path: any_path_h, /) -> ini_config_h | None:
-    """"""
-    ini_config = cfpr.ConfigParser(
-        delimiters=INI_VALUE_ASSIGNEMENT,
-        comment_prefixes=INI_COMMENT_MARKER,
-        empty_lines_in_values=False,
-        interpolation=None,
-    )
-    ini_config.optionxform = lambda option: option
-    try:
-        # Returns DEFAULT <Section: DEFAULT> if path does not exist or is a folder
-        ini_config.read(path, encoding=sstm.getfilesystemencoding())
-    except cfpr.MissingSectionHeaderError:
-        return None
-
-    output = {
-        section: {parameter: value for parameter, value in parameters.items()}
-        for section, parameters in ini_config.items()
-        if section != cfpr.DEFAULTSECT
-    }
-    if output.__len__() == 0:
-        return None
-
-    return output
+    return imports + f"\n{SECTIONS} = (\n" + ",\n".join(sections) + ",\n)\n"
 
 
 def SaveRawConfigToINIDocument(
@@ -161,19 +129,21 @@ if __name__ == "__main__":
 
     parser = argument_parser_t(
         prog="python -m conf_ini_g.interface.storage.config",
-        description="Display or save a draft config specification based on an INI file.",
+        description="Display or save a draft config specification "
+        "based on an INI file.",
         allow_abbrev=False,
     )
     # type=argparse.FileType() => automatic file opening
     parser.add_argument(
-        dest="ini_document",
+        dest="ini_path",
         help="Input: Path to INI configuration file",
         metavar="INI_config_file",
     )
     # type=argparse.FileType('w', encoding=main_encoding) => automatic creation of file
     parser.add_argument(
         dest="draft_specification",
-        help="Output: Path to draft config specification file. If not passed, specification is displayed in console.",
+        help="Output: Path to draft config specification file. "
+        "If not passed, specification is displayed in console.",
         default=None,
         nargs="?",
         metavar="draft_spec_file",
@@ -186,22 +156,20 @@ if __name__ == "__main__":
     )
 
     arguments = parser.parse_args()
-    ini_path = path_t(arguments.ini_document)
+    ini_path = path_t(arguments.ini_path)
     draft_path = arguments.draft_specification
     main_should_overwrite = arguments.should_overwrite
 
-    if (main_error := ValidateInputPath(ini_path)) is not None:
-        print(main_error + "\n")
+    if (issue := ValidateInputPath(ini_path)) is not None:
+        print(issue + "\n")
         parser.print_help()
         sstm.exit(-1)
 
     if draft_path is not None:
         draft_path = path_t(draft_path)
-        main_error = ValidateOutputPath(
-            draft_path, should_overwrite=main_should_overwrite
-        )
-        if main_error is not None:
-            print(main_error + "\n")
+        issue = ValidateOutputPath(draft_path, should_overwrite=main_should_overwrite)
+        if issue is not None:
+            print(issue + "\n")
             parser.print_help()
             sstm.exit(-1)
 
