@@ -32,10 +32,8 @@
 from configparser import ConfigParser as config_t
 from configparser import ExtendedInterpolation
 
-from conf_ini_g.light.config import config_as_dict_h
-from conf_ini_g.standard.path_extension import any_path_h
-from conf_ini_g.standard.str_extension import ConvertedValue
-
+from conf_ini_g.extension.path import any_path_h
+from conf_ini_g.raw.config import ini_config_h
 
 _DEFAULT_OPTIONS = (
     ("delimiters", ("=",)),
@@ -45,7 +43,7 @@ _DEFAULT_OPTIONS = (
 )
 
 
-def NewConfigFromPath(path: any_path_h, /, **kwargs) -> config_as_dict_h:
+def NewConfigFromPath(path: any_path_h, /, **kwargs) -> ini_config_h:
     """"""
     options = kwargs.copy()
     for name, value in _DEFAULT_OPTIONS:
@@ -57,7 +55,10 @@ def NewConfigFromPath(path: any_path_h, /, **kwargs) -> config_as_dict_h:
     config.read(path)
 
     # config.sections(): Does not include the default section named configparser.DEFAULTSECT
-    return {
-        _nme: {_prm: ConvertedValue(_vle) for _prm, _vle in config[_nme].items()}
-        for _nme in config.sections()
-    }
+    return {_nme: dict(config[_nme]) for _nme in config.sections()}
+    # return {
+    #     _nme: {
+    #         _prm: _vle for _prm, _vle in config[_nme].items()
+    #     }
+    #     for _nme in config.sections()
+    # }
