@@ -31,12 +31,11 @@
 
 from openpyxl import load_workbook as WorkbookFromPath
 
-from conf_ini_g.light.config import config_as_dict_h
-from conf_ini_g.standard.path_extension import any_path_h
-from conf_ini_g.standard.str_extension import ConvertedValue
+from conf_ini_g.extension.path import any_path_h
+from conf_ini_g.raw.config import ini_config_h
 
 
-def NewConfigFromPath(path: any_path_h, /) -> config_as_dict_h:
+def NewConfigFromPath(path: any_path_h, /) -> ini_config_h:
     """"""
     output = {}
 
@@ -45,7 +44,7 @@ def NewConfigFromPath(path: any_path_h, /) -> config_as_dict_h:
         sheet = workbook[name]
         contents = {}
         for row in tuple(sheet.rows):
-            contents[row[0].value] = ConvertedValue(row[1].value)
+            contents[row[0].value] = row[1].value
 
         output[name] = contents
 
