@@ -29,19 +29,60 @@
 # The fact that you are presently reading this means that you have had
 # knowledge of the CeCILL license and that you accept its terms.
 
+import configparser as cfpr
+import sys as sstm
 from typing import Any
 
-import colorama as clrm
+from conf_ini_g.extension.path import any_path_h
+from conf_ini_g.extension.string import Flattened
+from conf_ini_g.interface.storage.constant import INI_COMMENT_MARKER
 
-from conf_ini_g.standard.str_extension import Flattened
-
-
-# Straight from the INI document, without value interpretation
-ini_config_h = dict[str, dict[str, str]]
-raw_config_h = dict[str, dict[str, Any]]  # With interpreted values
+ini_config_h = dict[str, dict[str, str]]  # Without value interpretation
+raw_config_h = dict[str, dict[str, Any]]  # With interpreted values, and possibly units
 any_raw_config_h = ini_config_h | raw_config_h
 
 
+INI_VALUE_ASSIGNMENT = "="
+
+
+def INIConfigFromINIDocument(
+    path: any_path_h,
+    /,
+    *,
+    arguments: raw_config_h = None,
+) -> ini_config_h | None:
+    """"""
+    ini_config = cfpr.ConfigParser(
+        delimiters=INI_VALUE_ASSIGNMENT,
+        comment_prefixes=INI_COMMENT_MARKER,
+        empty_lines_in_values=False,
+        interpolation=None,
+    )
+    ini_config.optionxform = lambda option: option
+    try:
+        # Returns DEFAULT <Section: DEFAULT> if path does not exist or is a folder
+        ini_config.read(path, encoding=sstm.getfilesystemencoding())
+    except cfpr.MissingSectionHeaderError:
+        return None
+
+    output = {
+        section: {parameter: value for parameter, value in parameters.items()}
+        for section, parameters in ini_config.items()
+        if section != cfpr.DEFAULTSECT
+    }
+    if arguments is not None:
+        for sct_name, parameters in arguments.items():
+            if sct_name not in output:
+                output[sct_name] = {}
+            for prm_name, value in parameters.items():
+                output[sct_name][prm_name] = value
+
+    if output.__len__() == 0:
+        return None
+
+    return output
+
+
 def AsStr(config: any_raw_config_h, /, *, in_html_format: bool = False) -> str:
     """"""
     output = []
@@ -53,9 +94,9 @@ def AsStr(config: any_raw_config_h, /, *, in_html_format: bool = False) -> str:
         newline = "<br/>"
         indentation = "&nbsp;"
     else:
-        section_color = clrm.Fore.GREEN
-        parameter_color = clrm.Fore.BLUE
-        color_reset = clrm.Fore.RESET
+        section_color = "[green]"
+        parameter_color = "[blue]"
+        color_reset = "[/]"
         newline = "\n"
         indentation = " "
 
