@@ -29,84 +29,102 @@
 # The fact that you are presently reading this means that you have had
 # knowledge of the CeCILL license and that you accept its terms.
 
-from __future__ import annotations
-
 import dataclasses as dtcl
+import sys as sstm
 import textwrap as text
-from typing import Any, Sequence
+from typing import Sequence
 
-import conf_ini_g.specification.unit as unit
-from conf_ini_g.specification.constant import UNIT_SECTION, UNIT_SEPARATOR
-from conf_ini_g.specification.section import section_t
+from rich import print as rprint
+from rich.text import Text as text_t
+
+from conf_ini_g.catalog.specification.parameter.choices import choices_t
+from conf_ini_g.extension.python import SpecificationPath
+from conf_ini_g.extension.type import TypeAsRichStr
+from conf_ini_g.specification.parameter.type import type_t
+from conf_ini_g.specification.parameter.unit import UNIT_SEPARATOR
+from conf_ini_g.specification.section.main import section_t
+from conf_ini_g.specification.section.unit import UNIT_SECTION
 
 
 @dtcl.dataclass(init=False, repr=False, eq=False)
 class config_t(list[section_t]):
-
-    updater: Any = None
-    has_default_value: Sequence[int] | None = None
+    spec_path: str = None
 
     def __init__(self, sections: Sequence[section_t], /) -> None:
         """
-        Raising exceptions is adapted here since execution cannot proceed without a valid specification
+        Raising exceptions is adapted here since execution cannot proceed without a
+        valid specification.
         """
-        if sections.__len__() == 0:
-            raise ValueError(
-                f"{self.__class__.__name__}: Must be instantiated from a non-empty iterable"
-            )
-        super().__init__(sections)
+        list.__init__(self, sections)
+        self._SetControllerChoices()  # After __init__ so that self iterator is usable
+        self.spec_path = SpecificationPath(sections)
 
         issues = self.Issues()
-        if issues is not None:
-            print("\n".join(issues))
-            raise ValueError("Invalid config specification")
+        if issues.__len__() > 0:
+            rprint(
+                self.spec_path,
+                "[red]Invalid specification[/]",
+                "\n".join(issues),
+                sep="\n",
+            )
+            sstm.exit(1)
 
-        self.AddUnitSection()
+    def _SetControllerChoices(self) -> None:
+        """"""
+        for section in self:
+            if (controller := section.controller) is None:
+                continue
+
+            controlling_parameter = self[controller.section][controller.parameter]
+            controlling_parameter.type = type_t.NewFromTypeHint(
+                choices_t.NewAnnotatedType(section.controlling_values)
+            )
 
     def AddUnitSection(self) -> None:
         """"""
         section = section_t(
             name=UNIT_SECTION,
             definition="Unit definitions",
-            description=f"Units defined in this section can be use in any other section "
+            description=f"Units can be used in any other section "
             f"to specify a parameter value as follows: "
-            f"numeric_value{UNIT_SEPARATOR}unit, e.g., 1.5'mm",
+            f"numerical_value{UNIT_SEPARATOR}unit, e.g., 1.5'mm.",
             basic=True,
             optional=True,
             category=UNIT_SECTION,
-            accept_unknown_parameters=True,
+            is_growable=True,
         )
         self.append(section)
 
     @property
-    def valid_section_names(self) -> Sequence[str]:
+    def section_names(self) -> Sequence[str]:
         """"""
         return tuple(_sct.name for _sct in self)
 
-    def Issues(self, /, *, pre_units: bool = True) -> Sequence[str] | None:
-        """
-        To be called before adding the automatically-added unit section
-        """
+    def Issues(self) -> list[str]:
+        """"""
         output = []
 
-        valid_names = self.valid_section_names
-        if valid_names.__len__() > set(valid_names).__len__():
+        if self.__len__() == 0:
+            output.append("spec_path: Empty specification")
+            return output
+
+        names = self.section_names
+        if names.__len__() > set(names).__len__():
             output.append("Specification with repeated section names")
 
         for section in self:
-            if pre_units and unit.IsUnitSection(section.name, possibly_fuzzy=True):
+            if not isinstance(section, section_t):
                 output.append(
-                    f"{UNIT_SECTION}: Reserved section name; "
-                    f"Implicitly added to all configurations; "
-                    f"Must not be used in specification (in any case combination)"
+                    f"{type(section).__name__}: Invalid section type; Expected={section_t.__name__}."
                 )
-            else:
-                output.extend(section.Issues())
+                continue
+
+            output.extend(section.Issues())
             if section.controller is not None:
                 if section.controller.section not in self:
                     output.append(
                         f"{section.controller.section}: "
-                        f'Unknown section declared as controller of section "{section.name}"'
+                        f'Unspecified section declared as controller of section "{section.name}"'
                     )
                 else:
                     controller_section = self[section.controller.section]
@@ -118,7 +136,7 @@ class config_t(list[section_t]):
                     if section.controller.parameter not in controller_section:
                         output.append(
                             f"{section.controller.section}.{section.controller.parameter}: "
-                            f'Unknown parameter declared as controller of section "{section.name}"'
+                            f'Unspecified parameter declared as controller of section "{section.name}"'
                         )
                     else:
                         controller_parameter = controller_section[
@@ -129,42 +147,45 @@ class config_t(list[section_t]):
                                 f"{section.controller.section}.{section.controller.parameter}: "
                                 f'Optional parameter declared as controller of section "{section.name}"'
                             )
-                        if controller_parameter.type_options.__len__() > 1:
-                            output.append(
-                                f"{section.controller.section}.{section.controller.parameter}: "
-                                f'Multi-type parameter declared as controller of section "{section.name}"'
-                            )
-
-        if output.__len__() == 0:
-            output = None
 
         return output
 
-    def __contains__(self, key: str) -> bool:
-        """"""
-        for section in self:
-            if key == section.name:
-                return True
-
-        return False
-
-    def __getitem__(self, key: int | str) -> section_t:
+    def _Item(self, key: str | int, /) -> section_t | None:
         """"""
         if isinstance(key, int):
-            raise KeyError(
-                f"{self.__class__.__name__}: Not meant to be accessed as a list"
-            )
+            return list.__getitem__(self, key)
 
         for section in self:
-            if key == section.name:
+            if section.name == key:
                 return section
 
-        raise KeyError(f"{key}: Not an existing section")
+        return None
+
+    def __contains__(self, key: str, /) -> bool:
+        """"""
+        return self._Item(key) is not None
+
+    def __getitem__(self, key: str | int, /) -> section_t:
+        """"""
+        item = self._Item(key)
+        if item is None:
+            raise KeyError(f"{key}: Not a section of config.")
+
+        return item
 
     def __str__(self) -> str:
         """"""
-        sections = (str(_sct) for _sct in self)
-        sections = "\n".join(sections)
-        sections = text.indent(sections, "    ")
+        return text_t.from_markup(self.__rich__()).plain
 
-        return f"{self.__class__.__name__[:-2].upper()}:\n{sections}"
+    def __rich__(self) -> str:
+        """"""
+        output = [
+            TypeAsRichStr(self),
+            f"    [blue]spec_path[/]={self.spec_path}"
+            f"[yellow]:{type(self.spec_path).__name__}[/]",
+        ]
+
+        for section in self:
+            output.append(text.indent(section.__rich__(), "    "))
+
+        return "\n".join(output)
